@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
 import uuid
 
 from functional.tests.volume.v1 import common
@@ -26,8 +25,8 @@ class VolumeTests(common.BaseVolumeTests):
 
     @classmethod
     def setUpClass(cls):
-        os.environ['OS_VOLUME_API_VERSION'] = '1'
-        opts = cls.get_show_opts(cls.FIELDS)
+        super(VolumeTests, cls).setUpClass()
+        opts = cls.get_opts(cls.FIELDS)
         raw_output = cls.openstack('volume create --size 1 ' + cls.NAME + opts)
         expected = cls.NAME + '\n'
         cls.assertOutput(expected, raw_output)
@@ -43,12 +42,12 @@ class VolumeTests(common.BaseVolumeTests):
         cls.assertOutput('', raw_output)
 
     def test_volume_list(self):
-        opts = self.get_list_opts(self.HEADERS)
+        opts = self.get_opts(self.HEADERS)
         raw_output = self.openstack('volume list' + opts)
         self.assertIn(self.NAME, raw_output)
 
     def test_volume_show(self):
-        opts = self.get_show_opts(self.FIELDS)
+        opts = self.get_opts(self.FIELDS)
         raw_output = self.openstack('volume show ' + self.NAME + opts)
         self.assertEqual(self.NAME + "\n", raw_output)
 
@@ -56,7 +55,7 @@ class VolumeTests(common.BaseVolumeTests):
         raw_output = self.openstack(
             'volume set --property a=b --property c=d ' + self.NAME)
         self.assertEqual("", raw_output)
-        opts = self.get_show_opts(["properties"])
+        opts = self.get_opts(["properties"])
         raw_output = self.openstack('volume show ' + self.NAME + opts)
         self.assertEqual("a='b', c='d'\n", raw_output)
 
@@ -67,12 +66,12 @@ class VolumeTests(common.BaseVolumeTests):
 
     def test_volume_set(self):
         self.openstack('volume set --description RAMAC ' + self.NAME)
-        opts = self.get_show_opts(["display_description", "display_name"])
+        opts = self.get_opts(["display_description", "display_name"])
         raw_output = self.openstack('volume show ' + self.NAME + opts)
         self.assertEqual("RAMAC\n" + self.NAME + "\n", raw_output)
 
     def test_volume_set_size(self):
         self.openstack('volume set --size 2 ' + self.NAME)
-        opts = self.get_show_opts(["display_name", "size"])
+        opts = self.get_opts(["display_name", "size"])
         raw_output = self.openstack('volume show ' + self.NAME + opts)
         self.assertEqual(self.NAME + "\n2\n", raw_output)
