@@ -12,6 +12,7 @@
 #
 
 import copy
+import mock
 
 from openstackclient.identity.v3 import role_assignment
 from openstackclient.tests import fakes
@@ -26,6 +27,15 @@ class TestRoleAssignment(identity_fakes.TestIdentityv3):
 
 class TestRoleAssignmentList(TestRoleAssignment):
 
+    columns = (
+        'Role',
+        'User',
+        'Group',
+        'Project',
+        'Domain',
+        'Inherited',
+    )
+
     def setUp(self):
         super(TestRoleAssignment, self).setUp()
 
@@ -77,7 +87,9 @@ class TestRoleAssignmentList(TestRoleAssignment):
         verifylist = []
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
         self.role_assignments_mock.list.assert_called_with(
@@ -87,10 +99,10 @@ class TestRoleAssignmentList(TestRoleAssignment):
             role=None,
             user=None,
             project=None,
-            os_inherit_extension_inherited_to=None)
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
 
-        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
-        self.assertEqual(columns, collist)
+        self.assertEqual(self.columns, columns)
         datalist = ((
             identity_fakes.role_id,
             identity_fakes.user_id,
@@ -135,10 +147,13 @@ class TestRoleAssignmentList(TestRoleAssignment):
             ('role', None),
             ('effective', False),
             ('inherited', False),
+            ('names', False),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
         self.role_assignments_mock.list.assert_called_with(
@@ -148,10 +163,10 @@ class TestRoleAssignmentList(TestRoleAssignment):
             project=None,
             role=None,
             effective=False,
-            os_inherit_extension_inherited_to=None)
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
 
-        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
-        self.assertEqual(columns, collist)
+        self.assertEqual(self.columns, columns)
         datalist = ((
             identity_fakes.role_id,
             identity_fakes.user_id,
@@ -196,10 +211,13 @@ class TestRoleAssignmentList(TestRoleAssignment):
             ('role', None),
             ('effective', False),
             ('inherited', False),
+            ('names', False),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
         self.role_assignments_mock.list.assert_called_with(
@@ -209,10 +227,10 @@ class TestRoleAssignmentList(TestRoleAssignment):
             project=None,
             role=None,
             user=None,
-            os_inherit_extension_inherited_to=None)
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
 
-        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
-        self.assertEqual(columns, collist)
+        self.assertEqual(self.columns, columns)
         datalist = ((
             identity_fakes.role_id,
             '',
@@ -257,10 +275,13 @@ class TestRoleAssignmentList(TestRoleAssignment):
             ('role', None),
             ('effective', False),
             ('inherited', False),
+            ('names', False),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
         self.role_assignments_mock.list.assert_called_with(
@@ -270,10 +291,10 @@ class TestRoleAssignmentList(TestRoleAssignment):
             project=None,
             role=None,
             user=None,
-            os_inherit_extension_inherited_to=None)
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
 
-        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
-        self.assertEqual(columns, collist)
+        self.assertEqual(self.columns, columns)
         datalist = ((
             identity_fakes.role_id,
             identity_fakes.user_id,
@@ -318,10 +339,13 @@ class TestRoleAssignmentList(TestRoleAssignment):
             ('role', None),
             ('effective', False),
             ('inherited', False),
+            ('names', False),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
         self.role_assignments_mock.list.assert_called_with(
@@ -331,10 +355,10 @@ class TestRoleAssignmentList(TestRoleAssignment):
             project=self.projects_mock.get(),
             role=None,
             user=None,
-            os_inherit_extension_inherited_to=None)
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
 
-        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
-        self.assertEqual(columns, collist)
+        self.assertEqual(self.columns, columns)
         datalist = ((
             identity_fakes.role_id,
             identity_fakes.user_id,
@@ -351,6 +375,65 @@ class TestRoleAssignmentList(TestRoleAssignment):
             ),)
         self.assertEqual(datalist, tuple(data))
 
+    def test_role_assignment_list_def_creds(self):
+
+        auth_ref = self.app.client_manager.auth_ref = mock.MagicMock()
+        auth_ref.project_id.return_value = identity_fakes.project_id
+        auth_ref.user_id.return_value = identity_fakes.user_id
+
+        self.role_assignments_mock.list.return_value = [
+            fakes.FakeResource(
+                None,
+                copy.deepcopy(
+                    identity_fakes.ASSIGNMENT_WITH_PROJECT_ID_AND_USER_ID),
+                loaded=True,
+            ),
+        ]
+
+        arglist = [
+            '--auth-user',
+            '--auth-project',
+        ]
+        verifylist = [
+            ('user', None),
+            ('group', None),
+            ('domain', None),
+            ('project', None),
+            ('role', None),
+            ('effective', False),
+            ('inherited', False),
+            ('names', False),
+            ('authuser', True),
+            ('authproject', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.role_assignments_mock.list.assert_called_with(
+            domain=None,
+            user=self.users_mock.get(),
+            group=None,
+            project=self.projects_mock.get(),
+            role=None,
+            effective=False,
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
+
+        self.assertEqual(self.columns, columns)
+        datalist = ((
+            identity_fakes.role_id,
+            identity_fakes.user_id,
+            '',
+            identity_fakes.project_id,
+            '',
+            False
+        ),)
+        self.assertEqual(datalist, tuple(data))
+
     def test_role_assignment_list_effective(self):
 
         self.role_assignments_mock.list.return_value = [
@@ -377,10 +460,13 @@ class TestRoleAssignmentList(TestRoleAssignment):
             ('role', None),
             ('effective', True),
             ('inherited', False),
+            ('names', False),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
         self.role_assignments_mock.list.assert_called_with(
@@ -390,10 +476,10 @@ class TestRoleAssignmentList(TestRoleAssignment):
             project=None,
             role=None,
             user=None,
-            os_inherit_extension_inherited_to=None)
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
 
-        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
-        self.assertEqual(columns, collist)
+        self.assertEqual(self.columns, columns)
         datalist = ((
             identity_fakes.role_id,
             identity_fakes.user_id,
@@ -438,10 +524,13 @@ class TestRoleAssignmentList(TestRoleAssignment):
             ('role', None),
             ('effective', False),
             ('inherited', True),
+            ('names', False),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
         self.role_assignments_mock.list.assert_called_with(
@@ -451,10 +540,10 @@ class TestRoleAssignmentList(TestRoleAssignment):
             project=None,
             role=None,
             user=None,
-            os_inherit_extension_inherited_to='projects')
+            os_inherit_extension_inherited_to='projects',
+            include_names=False)
 
-        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
-        self.assertEqual(columns, collist)
+        self.assertEqual(self.columns, columns)
         datalist = ((
             identity_fakes.role_id,
             identity_fakes.user_id,
@@ -470,3 +559,125 @@ class TestRoleAssignmentList(TestRoleAssignment):
             True
             ),)
         self.assertEqual(datalist, tuple(data))
+
+    def test_role_assignment_list_include_names(self):
+
+        self.role_assignments_mock.list.return_value = [
+            fakes.FakeResource(
+                None,
+                copy.deepcopy(
+                    identity_fakes
+                    .ASSIGNMENT_WITH_PROJECT_ID_AND_USER_ID_INCLUDE_NAMES),
+                loaded=True,
+            ),
+            fakes.FakeResource(
+                None,
+                copy.deepcopy(
+                    identity_fakes
+                    .ASSIGNMENT_WITH_DOMAIN_ID_AND_USER_ID_INCLUDE_NAMES),
+                loaded=True,
+            ),
+        ]
+
+        arglist = ['--names']
+        verifylist = [
+            ('user', None),
+            ('group', None),
+            ('domain', None),
+            ('project', None),
+            ('role', None),
+            ('effective', False),
+            ('inherited', False),
+            ('names', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # DisplayCommandBase.take_action() returns two tuples
+
+        # This test will not run correctly until the patch in the python
+        # client is merged. Once that is done 'data' should return the
+        # correct information
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.role_assignments_mock.list.assert_called_with(
+            domain=None,
+            group=None,
+            effective=False,
+            project=None,
+            role=None,
+            user=None,
+            os_inherit_extension_inherited_to=None,
+            include_names=True)
+
+        collist = ('Role', 'User', 'Group', 'Project', 'Domain', 'Inherited')
+        self.assertEqual(columns, collist)
+
+        datalist1 = ((
+            identity_fakes.role_name,
+            '@'.join([identity_fakes.user_name, identity_fakes.domain_name]),
+            '',
+            '@'.join([identity_fakes.project_name,
+                      identity_fakes.domain_name]),
+            '',
+            False
+        ), (identity_fakes.role_name,
+            '@'.join([identity_fakes.user_name, identity_fakes.domain_name]),
+            '',
+            '',
+            identity_fakes.domain_name,
+            False
+            ),)
+        self.assertEqual(tuple(data), datalist1)
+
+    def test_role_assignment_list_domain_role(self):
+
+        self.role_assignments_mock.list.return_value = [
+            fakes.FakeResource(
+                None,
+                copy.deepcopy(
+                    identity_fakes.ASSIGNMENT_WITH_DOMAIN_ROLE),
+                loaded=True,
+            ),
+        ]
+
+        arglist = [
+            '--role', identity_fakes.ROLE_2['name'],
+            '--role-domain', identity_fakes.domain_name
+        ]
+        verifylist = [
+            ('user', None),
+            ('group', None),
+            ('domain', None),
+            ('project', None),
+            ('role', identity_fakes.ROLE_2['name']),
+            ('effective', False),
+            ('inherited', False),
+            ('names', False),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.role_assignments_mock.list.assert_called_with(
+            domain=None,
+            user=None,
+            group=None,
+            project=None,
+            role=self.roles_mock.get(),
+            effective=False,
+            os_inherit_extension_inherited_to=None,
+            include_names=False)
+
+        self.assertEqual(self.columns, columns)
+        datalist = ((
+            identity_fakes.ROLE_2['id'],
+            identity_fakes.user_id,
+            '',
+            '',
+            identity_fakes.domain_id,
+            False
+        ),)
+        self.assertEqual(datalist, tuple(data))
